@@ -1,8 +1,8 @@
 package Device::Firmata::IO::NetIO;
 
-=head1 Device::Firmata::IO::NetIO
+=head1 Name
 
-Implements the low level TCP/IP server socket IO.
+Device::Firmata::IO::NetIO - implements the low level TCP/IP server socket IO.
 
 =cut
 
@@ -17,9 +17,9 @@ use Device::Firmata::Base
     FIRMATA_ATTRIBS => {
     };
 
-=head2 METHODS
+=head1 METHODS
 
-=head3 listen ( host, port )
+=head2 listen ( host, port, [opts] )
 
 Start a TCP server bound to given local address and port for the Firmata device to connect to. Returns a C<Device::Firmata::IO::NetIO> object. Typically called by method C<listen> of L<Device::Firmata>. An implementation example can be found in file F<examples/example-tcpserver.pl>.
 
@@ -50,7 +50,7 @@ sub listen {
 	return $self;
 }
 
-=head3 accept ( timeout )
+=head2 accept ( timeout )
 
 Wait until timeout seconds for an Firmata device to connect. Returns a L<Device::Firmata::Platform> object on success or C<undef>. An implementation example can be found in file F<examples/example-tcpserver.pl>.
 
@@ -79,7 +79,7 @@ sub accept {
 	return undef;
 }
 
-=head3 close ( )
+=head2 close ( )
 
 Closes the TCP server socket and disconnects all Firmata devices. An implementation example can be found in file F<examples/example-tcpserver.pl>.
 
@@ -103,7 +103,7 @@ sub close {
 	}
 }
 
-=head3 attach ( connectedSocket )
+=head2 attach ( connectedSocket, [opts] )
 
 Assign a connected L<IO::Socket::INET> as IO port and return a L<Device::Firmata::Platform> object. Typically used internally by the C<accept()> method.
 
@@ -142,7 +142,7 @@ sub attach {
   return $platform;
 }
 
-=head3 poll ( timeout )
+=head2 poll ( timeout )
 
 Wait for timeout seconds for data from Firmata devices. If data is received the method C<poll> of L<Device::Firmata::Platform> will be called for processing. An implementation example can be found in file F<examples/example-tcpserver.pl>.
 
@@ -191,9 +191,9 @@ use Device::Firmata::Base
 
 =head2 METHODS
 
-=head3 attach ( connectedSocket )
+=head3 attach ( connectedSocket, [opts] )
 
-Assign a connected L<IO::Socket::INET> as IO port and return a C<Device::Firmata::IO::NetIO::Client> object. Typically used internally by the C<attach()> method of L<Device::Firmata::IO::NetIO>.
+Assign a connected L<IO::Socket::INET> as IO port and return a C<Device::Firmata::IO::NetIO::Client> object. Typically used internally by the C<attach()> method of C<Device::Firmata::IO::NetIO>.
 
 =cut
 
@@ -221,7 +221,7 @@ sub data_write {
 }
 
 
-=head3 data_read ( bytes )
+=head3 data_read ( numBytes )
 
 Fetch up to given number of bytes from the client socket. This function is non-blocking. Returns the received data. Typically used internally by L<Device::Firmata::Platform>.
 
@@ -240,7 +240,7 @@ sub data_read {
   return $buf;
 }
 
-=head3 close
+=head3 close ( )
 
 Close the TCP client socket to the Firmata device. The listening socket will not be affected. Typically used internally by L<Device::Firmata::Platform> and C<Device::Firmata::IO::NetIO>.
 
